@@ -7,6 +7,7 @@ for pytester only being available via the root directory.
 See "pytest_plugins in non-top-level conftest files" in
 https://docs.pytest.org/en/stable/deprecations.html
 """
+
 import pathlib
 import shutil
 import typing as t
@@ -14,10 +15,11 @@ import typing as t
 import pytest
 from _pytest.doctest import DoctestItem
 
+from libtmux.pane import Pane
 from libtmux.pytest_plugin import USING_ZSH
-
-if t.TYPE_CHECKING:
-    from libtmux.session import Session
+from libtmux.server import Server
+from libtmux.session import Session
+from libtmux.window import Window
 
 pytest_plugins = ["pytester"]
 
@@ -25,20 +27,24 @@ pytest_plugins = ["pytester"]
 @pytest.fixture(autouse=True)
 def add_doctest_fixtures(
     request: pytest.FixtureRequest,
-    doctest_namespace: t.Dict[str, t.Any],
+    doctest_namespace: dict[str, t.Any],
 ) -> None:
     """Configure doctest fixtures for pytest-doctest."""
     if isinstance(request._pyfuncitem, DoctestItem) and shutil.which("tmux"):
         request.getfixturevalue("set_home")
+        doctest_namespace["Server"] = Server
+        doctest_namespace["Session"] = Session
+        doctest_namespace["Window"] = Window
+        doctest_namespace["Pane"] = Pane
         doctest_namespace["server"] = request.getfixturevalue("server")
-        session: "Session" = request.getfixturevalue("session")
+        session: Session = request.getfixturevalue("session")
         doctest_namespace["session"] = session
-        doctest_namespace["window"] = session.attached_window
-        doctest_namespace["pane"] = session.attached_pane
+        doctest_namespace["window"] = session.active_window
+        doctest_namespace["pane"] = session.active_pane
         doctest_namespace["request"] = request
 
 
-@pytest.fixture(autouse=True, scope="function")
+@pytest.fixture(autouse=True)
 def set_home(
     monkeypatch: pytest.MonkeyPatch,
     user_path: pathlib.Path,
@@ -47,12 +53,11 @@ def set_home(
     monkeypatch.setenv("HOME", str(user_path))
 
 
-@pytest.fixture(autouse=True, scope="function")
+@pytest.fixture(autouse=True)
 def setup_fn(
     clear_env: None,
 ) -> None:
     """Function-level test configuration fixtures for pytest."""
-    pass
 
 
 @pytest.fixture(autouse=True, scope="session")
