@@ -4,6 +4,7 @@ libtmux.server
 ~~~~~~~~~~~~~~
 
 """
+
 import logging
 import os
 import pathlib
@@ -66,12 +67,12 @@ class Server(EnvironmentMixin):
     [Session($1 ...)]
 
     >>> server.sessions[0].windows
-    [Window(@1 1:..., Session($1 ...)]
+    [Window(@1 1:..., Session($1 ...))]
 
-    >>> server.sessions[0].attached_window
+    >>> server.sessions[0].active_window
     Window(@1 1:..., Session($1 ...))
 
-    >>> server.sessions[0].attached_pane
+    >>> server.sessions[0].active_pane
     Pane(%1 Window(@1 1:..., Session($1 ...)))
 
     References
@@ -110,8 +111,8 @@ class Server(EnvironmentMixin):
         **kwargs: t.Any,
     ) -> None:
         EnvironmentMixin.__init__(self, "-g")
-        self._windows: t.List[WindowDict] = []
-        self._panes: t.List[PaneDict] = []
+        self._windows: list[WindowDict] = []
+        self._panes: list[PaneDict] = []
 
         if socket_path is not None:
             self.socket_path = socket_path
@@ -158,9 +159,9 @@ class Server(EnvironmentMixin):
         """
         tmux_bin = shutil.which("tmux")
         if tmux_bin is None:
-            raise exc.TmuxCommandNotFound()
+            raise exc.TmuxCommandNotFound
 
-        cmd_args: t.List[str] = ["list-sessions"]
+        cmd_args: list[str] = ["list-sessions"]
         if self.socket_name:
             cmd_args.insert(0, f"-L{self.socket_name}")
         if self.socket_path:
@@ -173,14 +174,49 @@ class Server(EnvironmentMixin):
     #
     # Command
     #
-    def cmd(self, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
-        """Execute tmux command, rsepective of socket name and file, return output.
+    def cmd(
+        self,
+        cmd: str,
+        *args: t.Any,
+        target: t.Optional[t.Union[str, int]] = None,
+    ) -> tmux_cmd:
+        """Execute tmux command respective of socket name and file, return output.
 
         Examples
         --------
         >>> server.cmd('display-message', 'hi')
         <libtmux.common.tmux_cmd object at ...>
 
+        New session:
+
+        >>> server.cmd('new-session', '-d', '-P', '-F#{session_id}').stdout[0]
+        '$2'
+
+        >>> session.cmd('new-window', '-P').stdout[0]
+        'libtmux...:2.0'
+
+        Output of `tmux -L ... new-window -P -F#{window_id}` to a `Window` object:
+
+        >>> Window.from_window_id(window_id=session.cmd(
+        ... 'new-window', '-P', '-F#{window_id}').stdout[0], server=session.server)
+        Window(@4 3:..., Session($1 libtmux_...))
+
+        Create a pane from a window:
+
+        >>> window.cmd('split-window', '-P', '-F#{pane_id}').stdout[0]
+        '%5'
+
+        Output of `tmux -L ... split-window -P -F#{pane_id}` to a `Pane` object:
+
+        >>> Pane.from_pane_id(pane_id=window.cmd(
+        ... 'split-window', '-P', '-F#{pane_id}').stdout[0], server=window.server)
+        Pane(%... Window(@... ...:..., Session($1 libtmux_...)))
+
+        Parameters
+        ----------
+        target : str, optional
+            Optional custom target.
+
         Returns
         -------
         :class:`common.tmux_cmd`
@@ -191,25 +227,28 @@ class Server(EnvironmentMixin):
 
             Renamed from ``.tmux`` to ``.cmd``.
         """
-        cmd_args: t.List[t.Union[str, int]] = list(args)
+        svr_args: list[t.Union[str, int]] = [cmd]
+        cmd_args: list[t.Union[str, int]] = []
         if self.socket_name:
-            cmd_args.insert(0, f"-L{self.socket_name}")
+            svr_args.insert(0, f"-L{self.socket_name}")
         if self.socket_path:
-            cmd_args.insert(0, f"-S{self.socket_path}")
+            svr_args.insert(0, f"-S{self.socket_path}")
         if self.config_file:
-            cmd_args.insert(0, f"-f{self.config_file}")
+            svr_args.insert(0, f"-f{self.config_file}")
         if self.colors:
             if self.colors == 256:
-                cmd_args.insert(0, "-2")
+                svr_args.insert(0, "-2")
             elif self.colors == 88:
-                cmd_args.insert(0, "-8")
+                svr_args.insert(0, "-8")
             else:
-                raise exc.UnknownColorOption()
+                raise exc.UnknownColorOption
 
-        return tmux_cmd(*cmd_args, **kwargs)
+        cmd_args = ["-t", str(target), *args] if target is not None else [*args]
+
+        return tmux_cmd(*svr_args, *cmd_args)
 
     @property
-    def attached_sessions(self) -> t.List[Session]:
+    def attached_sessions(self) -> list[Session]:
         """Return active :class:`Session`s.
 
         Examples
@@ -221,22 +260,7 @@ class Server(EnvironmentMixin):
         -------
         list of :class:`Session`
         """
-        try:
-            sessions = self.sessions
-            attached_sessions = []
-
-            for session in sessions:
-                attached = session.session_attached
-                # for now session_active is a unicode
-                if attached != "0":
-                    logger.debug(f"session {session.name} attached")
-                    attached_sessions.append(session)
-                else:
-                    continue
-
-        except Exception:
-            return []
-        return attached_sessions
+        return self.sessions.filter(session_attached__noeq="1")
 
     def has_session(self, target_session: str, exact: bool = True) -> bool:
         """Return True if session exists.
@@ -263,12 +287,9 @@ class Server(EnvironmentMixin):
         if exact and has_gte_version("2.1"):
             target_session = f"={target_session}"
 
-        proc = self.cmd("has-session", "-t%s" % target_session)
+        proc = self.cmd("has-session", target=target_session)
 
-        if not proc.returncode:
-            return True
-
-        return False
+        return bool(not proc.returncode)
 
     def kill(self) -> None:
         """Kill tmux server.
@@ -307,7 +328,7 @@ class Server(EnvironmentMixin):
         ------
         :exc:`exc.BadSessionName`
         """
-        proc = self.cmd("kill-session", "-t%s" % target_session)
+        proc = self.cmd("kill-session", target=target_session)
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
@@ -328,7 +349,7 @@ class Server(EnvironmentMixin):
         """
         session_check_name(target_session)
 
-        proc = self.cmd("switch-client", "-t%s" % target_session)
+        proc = self.cmd("switch-client", target=target_session)
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
@@ -346,12 +367,7 @@ class Server(EnvironmentMixin):
         :exc:`exc.BadSessionName`
         """
         session_check_name(target_session)
-
-        tmux_args: t.Tuple[str, ...] = ()
-        if target_session:
-            tmux_args += ("-t%s" % target_session,)
-
-        proc = self.cmd("attach-session", *tmux_args)
+        proc = self.cmd("attach-session", target=target_session)
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
@@ -366,7 +382,7 @@ class Server(EnvironmentMixin):
         window_command: t.Optional[str] = None,
         x: t.Optional[t.Union[int, "DashLiteral"]] = None,
         y: t.Optional[t.Union[int, "DashLiteral"]] = None,
-        environment: t.Optional[t.Dict[str, str]] = None,
+        environment: t.Optional[dict[str, str]] = None,
         *args: t.Any,
         **kwargs: t.Any,
     ) -> Session:
@@ -445,11 +461,12 @@ class Server(EnvironmentMixin):
 
             if self.has_session(session_name):
                 if kill_session:
-                    self.cmd("kill-session", "-t%s" % session_name)
-                    logger.info("session %s exists. killed it." % session_name)
+                    self.cmd("kill-session", target=session_name)
+                    logger.info(f"session {session_name} exists. killed it.")
                 else:
+                    msg = f"Session named {session_name} exists"
                     raise exc.TmuxSessionExists(
-                        "Session named %s exists" % session_name,
+                        msg,
                     )
 
         logger.debug(f"creating session {session_name}")
@@ -459,7 +476,7 @@ class Server(EnvironmentMixin):
         if env:
             del os.environ["TMUX"]
 
-        tmux_args: t.Tuple[t.Union[str, int], ...] = (
+        tmux_args: tuple[t.Union[str, int], ...] = (
             "-P",
             "-F#{session_id}",  # output
         )
@@ -482,9 +499,6 @@ class Server(EnvironmentMixin):
         if y is not None:
             tmux_args += ("-y", y)
 
-        if window_command:
-            tmux_args += (window_command,)
-
         if environment:
             if has_gte_version("3.2"):
                 for k, v in environment.items():
@@ -494,6 +508,9 @@ class Server(EnvironmentMixin):
                     "Environment flag ignored, tmux 3.2 or newer required.",
                 )
 
+        if window_command:
+            tmux_args += (window_command,)
+
         proc = self.cmd("new-session", *tmux_args)
 
         if proc.stderr:
@@ -524,7 +541,7 @@ class Server(EnvironmentMixin):
         :meth:`.sessions.get() <libtmux._internal.query_list.QueryList.get()>` and
         :meth:`.sessions.filter() <libtmux._internal.query_list.QueryList.filter()>`
         """
-        sessions: t.List["Session"] = []
+        sessions: list[Session] = []
 
         try:
             for obj in fetch_objs(
@@ -545,7 +562,7 @@ class Server(EnvironmentMixin):
         :meth:`.windows.get() <libtmux._internal.query_list.QueryList.get()>` and
         :meth:`.windows.filter() <libtmux._internal.query_list.QueryList.filter()>`
         """
-        windows: t.List["Window"] = [
+        windows: list[Window] = [
             Window(server=self, **obj)
             for obj in fetch_objs(
                 list_cmd="list-windows",
@@ -564,7 +581,7 @@ class Server(EnvironmentMixin):
         :meth:`.panes.get() <libtmux._internal.query_list.QueryList.get()>` and
         :meth:`.panes.filter() <libtmux._internal.query_list.QueryList.filter()>`
         """
-        panes: t.List["Pane"] = [
+        panes: list[Pane] = [
             Pane(server=self, **obj)
             for obj in fetch_objs(
                 list_cmd="list-panes",
@@ -594,9 +611,9 @@ class Server(EnvironmentMixin):
                 f"{self.__class__.__name__}"
                 f"(socket_name={getattr(self, 'socket_name', 'default')})"
             )
-        elif self.socket_path is not None:
-            return f"{self.__class__.__name__}" f"(socket_path={self.socket_path})"
-        return f"{self.__class__.__name__}" f"(socket_path=/tmp/tmux-1000/default)"
+        if self.socket_path is not None:
+            return f"{self.__class__.__name__}(socket_path={self.socket_path})"
+        return f"{self.__class__.__name__}(socket_path=/tmp/tmux-1000/default)"
 
     #
     # Legacy: Redundant stuff we want to remove
@@ -618,7 +635,7 @@ class Server(EnvironmentMixin):
         )
         self.cmd("kill-server")
 
-    def _list_panes(self) -> t.List[PaneDict]:
+    def _list_panes(self) -> list[PaneDict]:
         """Return list of panes in :py:obj:`dict` form.
 
         Retrieved from ``$ tmux(1) list-panes`` stdout.
@@ -672,7 +689,7 @@ class Server(EnvironmentMixin):
         )
         return self.sessions.get(session_id=session_id, default=None)
 
-    def where(self, kwargs: t.Dict[str, t.Any]) -> t.List[Session]:
+    def where(self, kwargs: dict[str, t.Any]) -> list[Session]:
         """Filter through sessions, return list of :class:`Session`.
 
         .. deprecated:: 0.16
@@ -690,7 +707,7 @@ class Server(EnvironmentMixin):
         except IndexError:
             return []
 
-    def find_where(self, kwargs: t.Dict[str, t.Any]) -> t.Optional[Session]:
+    def find_where(self, kwargs: dict[str, t.Any]) -> t.Optional[Session]:
         """Filter through sessions, return first :class:`Session`.
 
         .. deprecated:: 0.16
@@ -705,7 +722,7 @@ class Server(EnvironmentMixin):
         )
         return self.sessions.get(default=None, **kwargs)
 
-    def _list_windows(self) -> t.List[WindowDict]:
+    def _list_windows(self) -> list[WindowDict]:
         """Return list of windows in :py:obj:`dict` form.
 
         Retrieved from ``$ tmux(1) list-windows`` stdout.
@@ -742,7 +759,7 @@ class Server(EnvironmentMixin):
         return self
 
     @property
-    def _sessions(self) -> t.List[SessionDict]:
+    def _sessions(self) -> list[SessionDict]:
         """Property / alias to return :meth:`~._list_sessions`.
 
         .. deprecated:: 0.16
@@ -751,11 +768,13 @@ class Server(EnvironmentMixin):
 
         """
         warnings.warn(
-            "Server._sessions is deprecated", category=DeprecationWarning, stacklevel=2
+            "Server._sessions is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
         )
         return self._list_sessions()
 
-    def _list_sessions(self) -> t.List["SessionDict"]:
+    def _list_sessions(self) -> list["SessionDict"]:
         """Return list of session object dictionaries.
 
         .. deprecated:: 0.16
@@ -769,7 +788,7 @@ class Server(EnvironmentMixin):
         )
         return [s.__dict__ for s in self.sessions]
 
-    def list_sessions(self) -> t.List[Session]:
+    def list_sessions(self) -> list[Session]:
         """Return list of :class:`Session` from the ``tmux(1)`` session.
 
         .. deprecated:: 0.16
@@ -797,6 +816,8 @@ class Server(EnvironmentMixin):
 
         """
         warnings.warn(
-            "Server.children is deprecated", category=DeprecationWarning, stacklevel=2
+            "Server.children is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
         )
         return self.sessions
