@@ -1,13 +1,13 @@
 """Test for libtmux Window object."""
+
 import logging
 import shutil
 import time
-import typing as t
 
 import pytest
 
 from libtmux import exc
-from libtmux.common import has_gte_version, has_lt_version
+from libtmux.common import has_gte_version, has_lt_version, has_version
 from libtmux.pane import Pane
 from libtmux.server import Server
 from libtmux.session import Session
@@ -157,8 +157,60 @@ def test_split_window_horizontal(session: Session) -> None:
     assert float(window.panes[0].width) <= ((float(window.width) + 1) / 2)
 
 
+@pytest.mark.filterwarnings("ignore:.*deprecated in favor of Window.split()")
+@pytest.mark.filterwarnings("ignore:.*vertical is not required to pass with direction.")
+def test_split_percentage(
+    session: Session,
+) -> None:
+    """Test deprecated percent param."""
+    window = session.new_window(window_name="split window size")
+    window.resize(height=100, width=100)
+    window_height_before = (
+        int(window.window_height) if isinstance(window.window_height, str) else 0
+    )
+    if has_version("3.4"):
+        pytest.skip(
+            "tmux 3.4 has a split-window bug."
+            + " See https://github.com/tmux/tmux/pull/3840.",
+        )
+    with pytest.warns(match="Deprecated in favor of size.*"):
+        pane = window.split_window(percent=10)
+        assert pane.pane_height == str(int(window_height_before * 0.1))
+
+
+def test_split_window_size(session: Session) -> None:
+    """Window.split_window() respects size."""
+    window = session.new_window(window_name="split_window window size")
+    window.resize(height=100, width=100)
+
+    if has_gte_version("3.1"):
+        pane = window.split_window(size=10)
+        assert pane.pane_height == "10"
+
+        pane = window.split_window(vertical=False, size=10)
+        assert pane.pane_width == "10"
+
+        pane = window.split_window(size="10%")
+        assert pane.pane_height == "8"
+
+        pane = window.split_window(vertical=False, size="10%")
+        assert pane.pane_width == "8"
+    else:
+        window_height_before = (
+            int(window.window_height) if isinstance(window.window_height, str) else 0
+        )
+        window_width_before = (
+            int(window.window_width) if isinstance(window.window_width, str) else 0
+        )
+        pane = window.split_window(size="10%")
+        assert pane.pane_height == str(int(window_height_before * 0.1))
+
+        pane = window.split_window(vertical=False, size="10%")
+        assert pane.pane_width == str(int(window_width_before * 0.1))
+
+
 @pytest.mark.parametrize(
-    "window_name_before,window_name_after",
+    ("window_name_before", "window_name_after"),
     [("test", "ha ha ha fjewlkjflwef"), ("test", "hello \\ wazzup 0")],
 )
 def test_window_rename(
@@ -249,7 +301,7 @@ def test_show_window_option_unknown(session: Session) -> None:
     """Window.show_window_option raises UnknownOption for bad option key."""
     window = session.new_window(window_name="test_window")
 
-    cmd_exception: t.Type[exc.OptionError] = exc.UnknownOption
+    cmd_exception: type[exc.OptionError] = exc.UnknownOption
     if has_gte_version("3.0"):
         cmd_exception = exc.InvalidOption
     with pytest.raises(cmd_exception):
@@ -345,7 +397,7 @@ def test_empty_window_name(session: Session) -> None:
 )
 def test_split_window_with_environment(
     session: Session,
-    environment: t.Dict[str, str],
+    environment: dict[str, str],
 ) -> None:
     """Verify splitting window with environment variables."""
     env = shutil.which("env")
