@@ -1,15 +1,19 @@
 """Test for libtmux Window object."""
+
 import logging
 import shutil
 import time
-import typing as t
 
 import pytest
 
 from libtmux import exc
 from libtmux._internal.query_list import ObjectDoesNotExist
-from libtmux.common import has_gte_version, has_lt_version, has_version
-from libtmux.constants import ResizeAdjustmentDirection
+from libtmux.common import has_gte_version, has_lt_version, has_lte_version
+from libtmux.constants import (
+    PaneDirection,
+    ResizeAdjustmentDirection,
+    WindowDirection,
+)
 from libtmux.pane import Pane
 from libtmux.server import Server
 from libtmux.session import Session
@@ -25,66 +29,66 @@ def test_select_window(session: Session) -> None:
     # for now however, let's get the index from the first window.
     assert window_count == 1
 
-    assert session.attached_window.window_index is not None
-    window_base_index = int(session.attached_window.window_index)
+    assert session.active_window.window_index is not None
+    window_base_index = int(session.active_window.window_index)
 
     window = session.new_window(window_name="testing 3")
 
     # self.assertEqual(2,
-    # int(session.attached_window.index))
+    # int(session.active_window.index))
     assert window.window_index is not None
     assert int(window_base_index) + 1 == int(window.window_index)
 
     session.select_window(str(window_base_index))
-    assert window_base_index == int(session.attached_window.window_index)
+    assert window_base_index == int(session.active_window.window_index)
 
     session.select_window("testing 3")
-    assert session.attached_window.window_index is not None
-    assert int(window_base_index) + 1 == int(session.attached_window.window_index)
+    assert session.active_window.window_index is not None
+    assert int(window_base_index) + 1 == int(session.active_window.window_index)
 
     assert len(session.windows) == 2
 
 
 def test_fresh_window_data(session: Session) -> None:
     """Verify window data is fresh."""
-    attached_window = session.attached_window
-    assert attached_window is not None
-    pane_base_idx = attached_window.show_window_option("pane-base-index", g=True)
+    active_window = session.active_window
+    assert active_window is not None
+    pane_base_idx = active_window.show_window_option("pane-base-index", g=True)
     assert pane_base_idx is not None
     pane_base_index = int(pane_base_idx)
 
     assert len(session.windows) == 1
 
-    assert len(session.attached_window.panes) == 1
+    assert len(session.active_window.panes) == 1
     current_windows = len(session.windows)
     assert session.session_id != "@0"
     assert current_windows == 1
 
-    assert len(session.attached_window.panes) == 1
+    assert len(session.active_window.panes) == 1
     assert isinstance(session.server, Server)
-    # len(session.attached_window.panes))
+    # len(session.active_window.panes))
 
     assert len(session.windows), 1
-    assert len(session.attached_window.panes) == 1
+    assert len(session.active_window.panes) == 1
     for w in session.windows:
         assert isinstance(w, Window)
-    window = session.attached_window
+    window = session.active_window
     assert isinstance(window, Window)
-    assert len(session.attached_window.panes) == 1
-    window.split_window()
+    assert len(session.active_window.panes) == 1
+    window.split()
 
-    attached_window = session.attached_window
-    assert attached_window is not None
-    attached_window.select_pane(pane_base_index)
+    active_window = session.active_window
+    assert active_window is not None
+    active_window.select_pane(pane_base_index)
 
-    attached_pane = session.attached_pane
-    assert attached_pane is not None
-    attached_pane.send_keys("cd /srv/www/flaskr")
+    active_pane = session.active_pane
+    assert active_pane is not None
+    active_pane.send_keys("cd /srv/www/flaskr")
 
-    attached_window.select_pane(pane_base_index + 1)
-    attached_pane = session.attached_pane
-    assert attached_pane is not None
-    attached_pane.send_keys("source .venv/bin/activate")
+    active_window.select_pane(pane_base_index + 1)
+    active_pane = session.active_pane
+    assert active_pane is not None
+    active_pane.send_keys("source .venv/bin/activate")
     session.new_window(window_name="second")
     current_windows += 1
     assert current_windows == len(session.windows)
@@ -103,26 +107,26 @@ def test_newest_pane_data(session: Session) -> None:
     window = session.new_window(window_name="test", attach=True)
     assert isinstance(window, Window)
     assert len(window.panes) == 1
-    window.split_window(attach=True)
+    window.split(attach=True)
 
     assert len(window.panes) == 2
-    # note: the below used to accept -h, removing because split_window now
+    # note: the below used to accept -h, removing because split now
     # has attach as its only argument now
-    window.split_window(attach=True)
+    window.split(attach=True)
     assert len(window.panes) == 3
 
 
-def test_attached_pane(session: Session) -> None:
-    """Window.attached_window returns active Pane."""
-    window = session.attached_window  # current window
-    assert isinstance(window.attached_pane, Pane)
+def test_active_pane(session: Session) -> None:
+    """Window.active_window returns active Pane."""
+    window = session.active_window  # current window
+    assert isinstance(window.active_pane, Pane)
 
 
-def test_split_window(session: Session) -> None:
-    """Window.split_window() splits window, returns new Pane, vertical."""
+def test_split(session: Session) -> None:
+    """Window.split() splits window, returns new Pane, vertical."""
     window_name = "test split window"
     window = session.new_window(window_name=window_name, attach=True)
-    pane = window.split_window()
+    pane = window.split()
     assert len(window.panes) == 2
     assert isinstance(pane, Pane)
 
@@ -133,12 +137,12 @@ def test_split_window(session: Session) -> None:
     assert float(first_pane.pane_height) <= ((float(window.window_width) + 1) / 2)
 
 
-def test_split_window_shell(session: Session) -> None:
-    """Window.split_window() splits window, returns new Pane, vertical."""
+def test_split_shell(session: Session) -> None:
+    """Window.split() splits window, returns new Pane, vertical."""
     window_name = "test split window"
     cmd = "sleep 1m"
     window = session.new_window(window_name=window_name, attach=True)
-    pane = window.split_window(shell=cmd)
+    pane = window.split(shell=cmd)
     assert len(window.panes) == 2
     assert isinstance(pane, Pane)
 
@@ -155,11 +159,11 @@ def test_split_window_shell(session: Session) -> None:
         assert pane.pane_start_command == cmd
 
 
-def test_split_window_horizontal(session: Session) -> None:
-    """Window.split_window() splits window, returns new Pane, horizontal."""
+def test_split_horizontal(session: Session) -> None:
+    """Window.split() splits window, returns new Pane, horizontal."""
     window_name = "test split window"
     window = session.new_window(window_name=window_name, attach=True)
-    pane = window.split_window(vertical=False)
+    pane = window.split(direction=PaneDirection.Right)
     assert len(window.panes) == 2
     assert isinstance(pane, Pane)
 
@@ -171,39 +175,22 @@ def test_split_window_horizontal(session: Session) -> None:
     assert float(first_pane.pane_width) <= ((float(window.window_width) + 1) / 2)
 
 
-def test_split_percentage(session: Session) -> None:
-    """Test deprecated percent param."""
-    window = session.new_window(window_name="split window size")
-    window.resize(height=100, width=100)
-    window_height_before = (
-        int(window.window_height) if isinstance(window.window_height, str) else 0
-    )
-    if has_version("3.4"):
-        pytest.skip(
-            "tmux 3.4 has a split-window bug."
-            + " See https://github.com/tmux/tmux/pull/3840."
-        )
-    with pytest.warns(match="Deprecated in favor of size.*"):
-        pane = window.split_window(percent=10)
-        assert pane.pane_height == str(int(window_height_before * 0.1))
-
-
-def test_split_window_size(session: Session) -> None:
-    """Window.split_window() respects size."""
+def test_split_size(session: Session) -> None:
+    """Window.split() respects size."""
     window = session.new_window(window_name="split window size")
     window.resize(height=100, width=100)
 
     if has_gte_version("3.1"):
-        pane = window.split_window(size=10)
+        pane = window.split(size=10)
         assert pane.pane_height == "10"
 
-        pane = window.split_window(vertical=False, size=10)
+        pane = window.split(direction=PaneDirection.Right, size=10)
         assert pane.pane_width == "10"
 
-        pane = window.split_window(size="10%")
+        pane = window.split(size="10%")
         assert pane.pane_height == "8"
 
-        pane = window.split_window(vertical=False, size="10%")
+        pane = window.split(direction=PaneDirection.Right, size="10%")
         assert pane.pane_width == "8"
     else:
         window_height_before = (
@@ -212,15 +199,15 @@ def test_split_window_size(session: Session) -> None:
         window_width_before = (
             int(window.window_width) if isinstance(window.window_width, str) else 0
         )
-        pane = window.split_window(size="10%")
+        pane = window.split(size="10%")
         assert pane.pane_height == str(int(window_height_before * 0.1))
 
-        pane = window.split_window(vertical=False, size="10%")
+        pane = window.split(direction=PaneDirection.Right, size="10%")
         assert pane.pane_width == str(int(window_width_before * 0.1))
 
 
 @pytest.mark.parametrize(
-    "window_name_before,window_name_after",
+    ("window_name_before", "window_name_after"),
     [("test", "ha ha ha fjewlkjflwef"), ("test", "hello \\ wazzup 0")],
 )
 def test_window_rename(
@@ -235,16 +222,16 @@ def test_window_rename(
     session.set_option("automatic-rename", "off")
     window = session.new_window(window_name=window_name_before, attach=True)
 
-    assert window == session.attached_window
+    assert window == session.active_window
     assert window.window_name == window_name_before
 
     window.rename_window(window_name_after)
 
-    window = session.attached_window
+    window = session.active_window
 
     assert window.window_name == window_name_after
 
-    window = session.attached_window
+    window = session.active_window
 
     assert window.window_name == window_name_after
 
@@ -255,7 +242,7 @@ def test_kill_window(session: Session) -> None:
     # create a second window to not kick out the client.
     # there is another way to do this via options too.
 
-    w = session.attached_window
+    w = session.active_window
 
     assert w.window_id is not None
 
@@ -310,7 +297,7 @@ def test_show_window_option_unknown(session: Session) -> None:
     """Window.show_window_option raises UnknownOption for bad option key."""
     window = session.new_window(window_name="test_window")
 
-    cmd_exception: t.Type[exc.OptionError] = exc.UnknownOption
+    cmd_exception: type[exc.OptionError] = exc.UnknownOption
     if has_gte_version("3.0"):
         cmd_exception = exc.InvalidOption
     with pytest.raises(cmd_exception):
@@ -379,7 +366,7 @@ def test_empty_window_name(session: Session) -> None:
     session.set_option("automatic-rename", "off")
     window = session.new_window(window_name="''", attach=True)
 
-    assert window == session.attached_window
+    assert window == session.active_window
     assert window.window_name == "''"
     assert session.session_name is not None
 
@@ -404,16 +391,16 @@ def test_empty_window_name(session: Session) -> None:
         {"ENV_VAR_1": "pane_1", "ENV_VAR_2": "pane_2"},
     ],
 )
-def test_split_window_with_environment(
+def test_split_with_environment(
     session: Session,
-    environment: t.Dict[str, str],
+    environment: dict[str, str],
 ) -> None:
     """Verify splitting window with environment variables."""
     env = shutil.which("env")
     assert env is not None, "Cannot find usable `env` in Path."
 
-    window = session.new_window(window_name="split_window_with_environment")
-    pane = window.split_window(
+    window = session.new_window(window_name="split_with_environment")
+    pane = window.split(
         shell=f"{env} PS1='$ ' sh",
         environment=environment,
     )
@@ -425,11 +412,37 @@ def test_split_window_with_environment(
         assert pane.capture_pane()[-2] == v
 
 
+@pytest.mark.skipif(
+    has_lte_version("3.1"),
+    reason="3.2 has the -Z flag on split-window",
+)
+def test_split_window_zoom(
+    session: Session,
+) -> None:
+    """Verify splitting window with zoom."""
+    window_without_zoom = session.new_window(window_name="split_without_zoom")
+    window_with_zoom = session.new_window(window_name="split_with_zoom")
+    pane_without_zoom = window_without_zoom.split(
+        zoom=False,
+    )
+    pane_with_zoom = window_with_zoom.split(
+        zoom=True,
+    )
+
+    assert pane_without_zoom.width == pane_without_zoom.window_width
+    assert pane_without_zoom.height is not None
+    assert pane_without_zoom.window_height is not None
+    assert pane_without_zoom.height < pane_without_zoom.window_height
+
+    assert pane_with_zoom.width == pane_with_zoom.window_width
+    assert pane_with_zoom.height == pane_with_zoom.window_height
+
+
 @pytest.mark.skipif(
     has_gte_version("3.0"),
     reason="3.0 has the -e flag on split-window",
 )
-def test_split_window_with_environment_logs_warning_for_old_tmux(
+def test_split_with_environment_logs_warning_for_old_tmux(
     session: Session,
     caplog: pytest.LogCaptureFixture,
 ) -> None:
@@ -437,8 +450,8 @@ def test_split_window_with_environment_logs_warning_for_old_tmux(
     env = shutil.which("env")
     assert env is not None, "Cannot find usable `env` in Path."
 
-    window = session.new_window(window_name="split_window_with_environment")
-    window.split_window(
+    window = session.new_window(window_name="split_with_environment")
+    window.split(
         shell=f"{env} PS1='$ ' sh",
         environment={"ENV_VAR": "pane"},
     )
@@ -458,7 +471,7 @@ def test_resize(
     """Verify resizing window."""
     session.cmd("detach-client", "-s")
 
-    window = session.attached_window
+    window = session.active_window
     window_height_adjustment = 10
 
     assert window.window_height is not None
@@ -492,7 +505,7 @@ def test_resize(
         adjustment=window_height_adjustment * 2,
     )
     assert window_height_before + (window_height_adjustment * 2) == int(
-        window.window_height
+        window.window_height,
     )
 
     # Adjustment: Up
@@ -526,3 +539,62 @@ def test_resize(
     )
     window_height_expanded = int(window.window_height)
     assert window_height_before < window_height_expanded
+
+
+@pytest.mark.skipif(
+    has_lt_version("3.2"),
+    reason="Only 3.2+ has the -a and -b flag on new-window",
+)
+def test_new_window_with_direction(
+    session: Session,
+) -> None:
+    """Verify new window with direction."""
+    window = session.active_window
+    window.refresh()
+
+    window_initial = session.new_window(window_name="Example")
+    assert window_initial.window_index == "2"
+
+    window_before = window_initial.new_window(
+        window_name="Window before",
+        direction=WindowDirection.Before,
+    )
+    window_initial.refresh()
+    assert window_before.window_index == "2"
+    assert window_initial.window_index == "3"
+
+    window_after = window_initial.new_window(
+        window_name="Window after",
+        direction=WindowDirection.After,
+    )
+    window_initial.refresh()
+    window_after.refresh()
+    assert window_after.window_index == "4"
+    assert window_initial.window_index == "3"
+    assert window_before.window_index == "2"
+
+
+@pytest.mark.skipif(
+    has_gte_version("3.2"),
+    reason="Only 3.2+ has the -a and -b flag on new-window",
+)
+def test_new_window_with_direction_logs_warning_for_old_tmux(
+    session: Session,
+    caplog: pytest.LogCaptureFixture,
+) -> None:
+    """Verify new window with direction create a warning if tmux is too old."""
+    window = session.active_window
+    window.refresh()
+
+    window.new_window(
+        window_name="window_with_direction",
+        direction=WindowDirection.After,
+    )
+
+    assert any(
+        "Window target ignored" in record.msg for record in caplog.records
+    ), "Warning missing"
+
+    assert any(
+        "Direction flag ignored" in record.msg for record in caplog.records
+    ), "Warning missing"
